@@ -1,13 +1,11 @@
 import os
 import lightning as L
-import datetime
 from scipy.optimize import differential_evolution
 import numpy as np
-
-
-# PyTorch TensorBoard support
+import socket
+import datetime
+from dateutil.tz import tzlocal
 from torch.utils.tensorboard import SummaryWriter
-from spotPython.utils.file import get_experiment_name, get_spot_tensorboard_path
 
 
 def fun_control_init(
@@ -15,11 +13,17 @@ def fun_control_init(
     _L_out=None,
     PREFIX=None,
     TENSORBOARD_CLEAN=False,
+    SUMMARY_WRITER=True,
     accelerator="auto",
+    data=None,
+    data_dir="./data",
+    data_module=None,
+    data_set=None,
     design=None,
     device=None,
     devices=1,
     enable_progress_bar=False,
+    EXPERIMENT_NAME=None,
     fun_evals=15,
     fun_repeats=1,
     infill_criterion="y",
@@ -35,6 +39,7 @@ def fun_control_init(
     show_models=False,
     show_progress=True,
     sigma=0.0,
+    surrogate=None,
     task=None,
     test_seed=1234,
     test_size=0.4,
@@ -45,14 +50,24 @@ def fun_control_init(
     verbosity=0,
 ):
     """Initialize fun_control dictionary.
+
     Args:
         _L_in (int):
             The number of input features.
         _L_out (int):
             The number of output features.
-        acceleration (str):
+        accelerator (str):
             The accelerator to be used by the Lighting Trainer.
             It can be either "auto", "dp", "ddp", "ddp2", "ddp_spawn", "ddp_cpu", "gpu", "tpu".
+            Default is "auto".
+        data (object):
+            The data object. Default is None.
+        data_dir (str):
+            The directory to save the data. Default is "./data".
+        data_module (object):
+            The data module object. Default is None.
+        data_set (object):
+            The data set object. Default is None.
         device (str):
             The device to use for the training. It can be either "cpu", "mps", or "cuda".
         devices (str or int):
@@ -215,7 +230,7 @@ def fun_control_init(
             print(f"Moving TENSORBOARD_PATH: {TENSORBOARD_PATH} to TENSORBOARD_PATH_OLD: {TENSORBOARD_PATH_OLD}")
             os.rename(TENSORBOARD_PATH[:-1], TENSORBOARD_PATH_OLD)
     os.makedirs(TENSORBOARD_PATH, exist_ok=True)
-    if PREFIX is not None:
+    if PREFIX is not None and SUMMARY_WRITER:
         experiment_name = get_experiment_name(prefix=PREFIX)
         spot_tensorboard_path = get_spot_tensorboard_path(experiment_name)
         os.makedirs(spot_tensorboard_path, exist_ok=True)
@@ -238,10 +253,10 @@ def fun_control_init(
         "_L_out": _L_out,
         "accelerator": accelerator,
         "counter": 0,
-        "data": None,
-        "data_dir": "./data",
-        "data_module": None,
-        "data_set": None,
+        "data": data,
+        "data_dir": data_dir,
+        "data_module": data_module,
+        "data_set": data_set,
         "design": design,
         "device": device,
         "devices": devices,
@@ -436,7 +451,6 @@ def surrogate_control_init(
           for many situations. For example, for k=2 these are 30 000 iterations.
           Therefore we set this value to 1000.
 
-
     """
     surrogate_control = {
         "log_level": log_level,
@@ -487,3 +501,50 @@ def optimizer_control_init(
     """
     optimizer_control = {"max_iter": max_iter, "seed": seed}
     return optimizer_control
+
+
+def get_experiment_name(prefix: str = "00") -> str:
+    """Returns a unique experiment name with a given prefix.
+
+    Args:
+        prefix (str, optional): Prefix for the experiment name. Defaults to "00".
+
+    Returns:
+        str: Unique experiment name.
+
+    Examples:
+        >>> from spotPython.utils.file import get_experiment_name
+        >>> get_experiment_name(prefix="00")
+        00_ubuntu_2021-08-31_14-30-00
+    """
+    start_time = datetime.datetime.now(tzlocal())
+    HOSTNAME = socket.gethostname().split(".")[0]
+    experiment_name = prefix + "_" + HOSTNAME + "_" + str(start_time).split(".", 1)[0].replace(" ", "_")
+    experiment_name = experiment_name.replace(":", "-")
+    return experiment_name
+
+
+def get_spot_tensorboard_path(experiment_name):
+    """Get the path to the spot tensorboard files.
+
+    Args:
+        experiment_name (str): The name of the experiment.
+
+    Returns:
+        spot_tensorboard_path (str): The path to the folder where the spot tensorboard files are saved.
+    """
+    spot_tensorboard_path = os.environ.get("PATH_TENSORBOARD", "runs/spot_logs/")
+    spot_tensorboard_path = os.path.join(spot_tensorboard_path, experiment_name)
+    return spot_tensorboard_path
+
+
+def get_tensorboard_path(fun_control):
+    """Get the path to the tensorboard files.
+
+    Args:
+        fun_control (dict): The function control dictionary.
+
+    Returns:
+        tensorboard_path (str): The path to the folder where the tensorboard files are saved.
+    """
+    return fun_control["TENSORBOARD_PATH"]
