@@ -1,20 +1,21 @@
 import numpy as np
 from spotPython.fun.objectivefunctions import analytical
 from spotPython.spot import spot
+from spotPython.utils.init import fun_control_init, optimizer_control_init, surrogate_control_init, design_control_init
 
 def test_fit_surrogate():
     # number of initial points:
     ni = 0
     X_start = np.array([[0, 0], [0, 1], [1, 0], [1, 1], [1, 1]])
     fun = analytical().fun_sphere
-    lower = np.array([-1, -1])
-    upper = np.array([1, 1])
-    design_control={"init_size": ni}
+    fun_control = fun_control_init(
+        noise=False,
+        lower = np.array([-1, -1]),
+        upper = np.array([1, 1]),
+        show_progress=True,)
+    design_control = design_control_init(init_size=ni)
     S = spot.Spot(fun=fun,
-                noise=False,
-                lower = lower,
-                upper= upper,
-                show_progress=True,
+                fun_control=fun_control,            
                 design_control=design_control,)
     S.initialize_design(X_start=X_start)
     S.update_stats()
